﻿//
// ConsoleCSharp
//
// Copyright (c) 2016 http://www.curict.com
// This software is released under the MIT License, see LICENSE.txt.
//

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.SqlClient;
using Extensions;

namespace ConsoleCSharp
{
    class Program
    {
        static void Main(string[] args)
        {
            // 接続文字列。環境に合わせて修正してください
            String connectionString = "SERVER=LOCALHOST\\SQLEXPRESS;UID=sa2;PWD=sa2;DATABASE=Web";

            // 通常パターン
            Normal(connectionString);

            // 拡張メソッド(エクステンション)を使用してシンプルに
            UseExtension(connectionString);

            Console.ReadLine();
        }

        /// <summary>
        /// 通常パターン
        /// </summary>
        static private void Normal(string connectionString)
        {
            using (SqlConnection connection = new SqlConnection(connectionString))
            {
                // コネクションを開く
                connection.Open();

                // コマンド作成
                SqlCommand command = connection.CreateCommand();

                // SQL
                command.CommandText = "SELECT COUNT(*) FROM sys.objects WHERE type IN (@type1, @type2, @type3)";

                // SQLパラメータ設定
                SqlParameter param1 = new SqlParameter("@type1", SqlDbType.VarChar);
                param1.Value = "S";
                command.Parameters.Add(param1);

                SqlParameter param2 = new SqlParameter("@type2", SqlDbType.VarChar);
                param2.Value = "U";
                command.Parameters.Add(param2);

                SqlParameter param3 = new SqlParameter("@type3", SqlDbType.VarChar);
                param3.Value = "PK";
                command.Parameters.Add(param3);

                // コマンド実行
                object result = command.ExecuteScalar();

                // 結果表示
                Console.WriteLine(result.ToString());
            }
        }

        /// <summary>
        /// 拡張メソッド(エクステンション)を使用
        /// </summary>
        static private void UseExtension(string connectionString)
        {
            using (SqlConnection connection = new SqlConnection(connectionString))
            {
                // コネクションを開く
                connection.Open();

                // コマンド作成
                SqlCommand command = connection.CreateCommand();

                // SQL
                command.CommandText = "SELECT COUNT(*) FROM sys.objects WHERE type IN (@type1, @type2, @type3)";

                // SQLパラメータ設定
                List<SqlParameter> sqlParameters = new List<SqlParameter>();
                sqlParameters.AddSqlParameter(new SqlParameter("@type1", SqlDbType.VarChar)).Value = "S";
                sqlParameters.AddSqlParameter(new SqlParameter("@type2", SqlDbType.VarChar)).Value = "U";
                sqlParameters.AddSqlParameter(new SqlParameter("@type3", SqlDbType.VarChar)).Value = "PK";
                command.Parameters.AddParams(sqlParameters);

                // コマンド実行
                object result = command.ExecuteScalar();

                // 結果表示
                Console.WriteLine(result.ToString());
            }
        }    
    }
}
